<?php

namespace Drupal\nice_menus\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a nice menus settings form.
 */
class NiceMenusSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'nice_menus_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'nice_menus.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('nice_menus.settings');
    // Use JavaScript configuration setting.
    $form['nice_menus_js'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use JavaScript'),
      '#description' => $this->t('This will add Superfish jQuery to Nice menus. This is required for Nice menus to work properly in Internet Explorer.'),
      '#default_value' => $config->get('nice_menus_js'),
    ];

    $form['nice_menus_default_css'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use default css'),
      '#description' => $this->t('This will add default nice menus style.'),
      '#default_value' => $config->get('nice_menus_default_css'),
    ];

    $form['nice_menus_sf_options'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Advanced: Superfish options'),
      '#description' => $this->t('You can change the default Superfish options by filling out the desired values here. These only take effect if the Use JavaScript box above is checked.'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    ];

    // Mouse delay textfield for the time before the menus is closed.
    $form['nice_menus_sf_options']['nice_menus_sf_delay'] = [
      '#type' => 'number',
      '#title' => $this->t('Mouse delay'),
      '#description' => $this->t('The delay in milliseconds that the mouse can remain outside a submenu without it closing.'),
      '#default_value' => $config->get('nice_menus_sf_delay'),
      '#size' => 5,
    ];

    // Display speed of the animation for the menu to open/close.
    $form['nice_menus_sf_options']['nice_menus_sf_speed'] = [
      '#type' => 'select',
      '#title' => $this->t('Animation speed'),
      '#description' => $this->t('Speed of the menu open/close animation.'),
      '#options' => [
        'slow' => $this->t('slow'),
        'normal' => $this->t('normal'),
        'fast' => $this->t('fast'),
      ],
      '#default_value' => $config->get('nice_menus_sf_speed'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('nice_menus.settings')
      ->set('nice_menus_js', (bool) $form_state->getValue('nice_menus_js'))
      ->set('nice_menus_default_css', (bool) $form_state->getValue('nice_menus_default_css'))
      ->set('nice_menus_sf_delay', (int) $form_state->getValue('nice_menus_sf_delay'))
      ->set('nice_menus_sf_speed', $form_state->getValue('nice_menus_sf_speed'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
